@@ -83,9 +83,9 @@ class ExplicitEulerPython(NumericalApproximator):
         fl = fluxes_out[0]
 
         # Calculate the numerical approximation of the differential equation
-        dif_eq = (S - S0) / dt - sum(fl)
+        diff_eq = (S - S0) / dt - sum(fl)
 
-        return (dif_eq,           # Fun to set to zero
+        return (diff_eq,           # Fun to set to zero
                 fluxes_out[1],    # Min search
                 fluxes_out[2])    # Max search
 
@@ -142,8 +142,8 @@ class ExplicitEulerNumba(NumericalApproximator):
         fl = fluxes_out[0]
 
         # Calculate the numerical approximation of the differential equation
-        dif_eq = (S - S0) / dt - sum(fl)
+        diff_eq = (S - S0) / dt - sum(fl)
 
-        return (dif_eq,           # Fun to set to zero
+        return (diff_eq,           # Fun to set to zero
                 fluxes_out[1],    # Min search
                 fluxes_out[2])    # Max search
